# Pugh Torch

[![Build Status](https://github.com/BrianPugh/pugh_torch/workflows/Build%20Master/badge.svg)](https://github.com/BrianPugh/pugh_torch/actions)
[![Documentation](https://github.com/BrianPugh/pugh_torch/workflows/Documentation/badge.svg)](https://BrianPugh.github.io/pugh_torch)
[![Code Coverage](https://codecov.io/gh/BrianPugh/pugh_torch/branch/master/graph/badge.svg)](https://codecov.io/gh/BrianPugh/pugh_torch)

Functions, losses, and module blocks to share between experiments.

---

## Features
* Additional methods to TensorBoard summary writer for adding normalized images and semantic segmentation images.
* hetero_cross_entropy for cross_entropy loss across heterogeneous datasets

## Installation
**Stable Release:** `pip install pugh_torch`<br>
**Development Head:** `pip install git+https://github.com/BrianPugh/pugh_torch.git`

## Documentation
For full package documentation please visit [BrianPugh.github.io/pugh_torch](https://BrianPugh.github.io/pugh_torch).

***Free software: MIT license***

